@@ -12,9 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, List, Optional, Tuple, TypeVar, Union
+from typing import TYPE_CHECKING, List, Optional, Tuple
 
-from selenium import webdriver
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.common.actions import interaction
 from selenium.webdriver.common.actions.action_builder import ActionBuilder
@@ -24,14 +23,11 @@ from selenium.webdriver.common.actions.pointer_input import PointerInput
 from appium.webdriver.webelement import WebElement
 
 if TYPE_CHECKING:
-    # noinspection PyUnresolvedReferences
     from appium.webdriver.webdriver import WebDriver
 
-T = TypeVar('T', bound=Union['WebDriver', 'ActionHelpers'])
 
-
-class ActionHelpers(webdriver.Remote):
-    def scroll(self: T, origin_el: WebElement, destination_el: WebElement, duration: Optional[int] = None) -> T:
+class ActionHelpers:
+    def scroll(self, origin_el: WebElement, destination_el: WebElement, duration: Optional[int] = None) -> 'WebDriver':
         """Scrolls from one element to another
 
         Args:
@@ -72,9 +68,9 @@ class ActionHelpers(webdriver.Remote):
             actions.w3c_actions.pointer_action.move_to_location(dest_el_rect['x'], dest_el_rect['y'])
             actions.w3c_actions.pointer_action.release()
             actions.perform()
-        return self
+        return self  # type: ignore
 
-    def drag_and_drop(self: T, origin_el: WebElement, destination_el: WebElement) -> T:
+    def drag_and_drop(self, origin_el: WebElement, destination_el: WebElement) -> 'WebDriver':
         """Drag the origin element to the destination element
 
         Args:
@@ -90,9 +86,9 @@ class ActionHelpers(webdriver.Remote):
         actions.w3c_actions.pointer_action.move_to(destination_el)
         actions.w3c_actions.pointer_action.release()
         actions.perform()
-        return self
+        return self  # type: ignore
 
-    def tap(self: T, positions: List[Tuple[int, int]], duration: Optional[int] = None) -> T:
+    def tap(self, positions: List[Tuple[int, int]], duration: Optional[int] = None) -> 'WebDriver':
         """Taps on an particular place with up to five fingers, holding for a
         certain time
 
@@ -130,20 +126,19 @@ class ActionHelpers(webdriver.Remote):
                 x = position[0]
                 y = position[1]
 
-                # https://github.com/SeleniumHQ/selenium/blob/64447d4b03f6986337d1ca8d8b6476653570bcc1/py/selenium/webdriver/common/actions/pointer_input.py#L24
+                # https://github.com/SeleniumHQ/selenium/blob/trunk/py/selenium/webdriver/common/actions/pointer_input.py
                 new_input = actions.w3c_actions.add_pointer_input('touch', f'finger{finger}')
                 new_input.create_pointer_move(x=x, y=y)
-                new_input.create_pointer_down(MouseButton.LEFT)
+                new_input.create_pointer_down(button=MouseButton.LEFT)
                 if duration:
                     new_input.create_pause(duration / 1000)
                 else:
                     new_input.create_pause(0.1)
                 new_input.create_pointer_up(MouseButton.LEFT)
             actions.perform()
+        return self  # type: ignore
 
-        return self
-
-    def swipe(self: T, start_x: int, start_y: int, end_x: int, end_y: int, duration: int = 0) -> T:
+    def swipe(self, start_x: int, start_y: int, end_x: int, end_y: int, duration: int = 0) -> 'WebDriver':
         """Swipe from one point to another point, for an optional duration.
 
         Args:
@@ -167,9 +162,9 @@ class ActionHelpers(webdriver.Remote):
         actions.w3c_actions.pointer_action.move_to_location(end_x, end_y)
         actions.w3c_actions.pointer_action.release()
         actions.perform()
-        return self
+        return self  # type: ignore
 
-    def flick(self: T, start_x: int, start_y: int, end_x: int, end_y: int) -> T:
+    def flick(self, start_x: int, start_y: int, end_x: int, end_y: int) -> 'WebDriver':
         """Flick from one point to another point.
 
         Args:
@@ -191,4 +186,4 @@ class ActionHelpers(webdriver.Remote):
         actions.w3c_actions.pointer_action.move_to_location(end_x, end_y)
         actions.w3c_actions.pointer_action.release()
         actions.perform()
-        return self
+        return self  # type: ignore
