@@ -12,9 +12,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, List, TypeVar, Union
+from typing import TYPE_CHECKING, List
 
-from selenium import webdriver
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 
 from ..mobilecommand import MobileCommand as Command
 
@@ -22,13 +22,10 @@ if TYPE_CHECKING:
     # noinspection PyUnresolvedReferences
     from appium.webdriver.webdriver import WebDriver
 
-T = TypeVar('T', bound=Union['WebDriver', 'IME'])
-
-
-class IME(webdriver.Remote):
 
+class IME(CanExecuteCommands):
     @property
-    def available_ime_engines(self: T) -> List[str]:
+    def available_ime_engines(self) -> List[str]:
         """Get the available input methods for an Android device.
 
         Package and activity are returned (e.g., ['com.android.inputmethod.latin/.LatinIME'])
@@ -37,18 +34,18 @@ class IME(webdriver.Remote):
         Returns:
             :obj:`list` of :obj:`str`: The available input methods for an Android device
         """
-        return self.execute(Command.GET_AVAILABLE_IME_ENGINES, {})['value']
+        return self.execute(Command.GET_AVAILABLE_IME_ENGINES, {})['value']  # pylint: disable=unsubscriptable-object
 
-    def is_ime_active(self: T) -> bool:
+    def is_ime_active(self) -> bool:
         """Checks whether the device has IME service active.
         Android only.
 
         Returns:
             `True` if IME service is active
         """
-        return self.execute(Command.IS_IME_ACTIVE, {})['value']
+        return self.execute(Command.IS_IME_ACTIVE, {})['value']  # pylint: disable=unsubscriptable-object
 
-    def activate_ime_engine(self: T, engine: str) -> T:
+    def activate_ime_engine(self, engine: str) -> 'WebDriver':
         """Activates the given IME engine on the device.
 
         Android only.
@@ -60,13 +57,11 @@ class IME(webdriver.Remote):
         Returns:
             Union['WebDriver', 'IME']: Self instance
         """
-        data = {
-            'engine': engine
-        }
+        data = {'engine': engine}
         self.execute(Command.ACTIVATE_IME_ENGINE, data)
-        return self
+        return self  # type: ignore
 
-    def deactivate_ime_engine(self: T) -> T:
+    def deactivate_ime_engine(self) -> 'WebDriver':
         """Deactivates the currently active IME engine on the device.
 
         Android only.
@@ -75,10 +70,10 @@ class IME(webdriver.Remote):
             Union['WebDriver', 'IME']: Self instance
         """
         self.execute(Command.DEACTIVATE_IME_ENGINE, {})
-        return self
+        return self  # type: ignore
 
     @property
-    def active_ime_engine(self: T) -> str:
+    def active_ime_engine(self) -> str:
         """Returns the activity and package of the currently active IME engine
         (e.g., 'com.android.inputmethod.latin/.LatinIME').
 
@@ -87,18 +82,20 @@ class IME(webdriver.Remote):
         Returns:
             str: The activity and package of the currently active IME engine
         """
-        return self.execute(Command.GET_ACTIVE_IME_ENGINE, {})['value']
+        return self.execute(Command.GET_ACTIVE_IME_ENGINE, {})['value']  # pylint: disable=unsubscriptable-object
 
-    # pylint: disable=protected-access
-    # noinspection PyProtectedMember
-    def _addCommands(self) -> None:
-        self.command_executor._commands[Command.GET_AVAILABLE_IME_ENGINES] = \
-            ('GET', '/session/$sessionId/ime/available_engines')
-        self.command_executor._commands[Command.IS_IME_ACTIVE] = \
-            ('GET', '/session/$sessionId/ime/activated')
-        self.command_executor._commands[Command.ACTIVATE_IME_ENGINE] = \
-            ('POST', '/session/$sessionId/ime/activate')
-        self.command_executor._commands[Command.DEACTIVATE_IME_ENGINE] = \
-            ('POST', '/session/$sessionId/ime/deactivate')
-        self.command_executor._commands[Command.GET_ACTIVE_IME_ENGINE] = \
-            ('GET', '/session/$sessionId/ime/active_engine')
+    def _add_commands(self) -> None:
+        """Add IME commands. They are not in W3C spec."""
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.GET_AVAILABLE_IME_ENGINES] = (
+            'GET',
+            '/session/$sessionId/ime/available_engines',
+        )
+        commands[Command.IS_IME_ACTIVE] = ('GET', '/session/$sessionId/ime/activated')
+        commands[Command.ACTIVATE_IME_ENGINE] = ('POST', '/session/$sessionId/ime/activate')
+        commands[Command.DEACTIVATE_IME_ENGINE] = ('POST', '/session/$sessionId/ime/deactivate')
+        commands[Command.GET_ACTIVE_IME_ENGINE] = (
+            'GET',
+            '/session/$sessionId/ime/active_engine',
+        )
