@@ -12,21 +12,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, Any, Dict, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict
 
-from selenium import webdriver
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 
 from ..mobilecommand import MobileCommand as Command
 
 if TYPE_CHECKING:
-    # noinspection PyUnresolvedReferences
     from appium.webdriver.webdriver import WebDriver
 
-T = TypeVar('T', bound=Union['WebDriver', 'Settings'])
 
-
-class Settings(webdriver.Remote):
-    def get_settings(self: T) -> Dict[str, Any]:
+class Settings(CanExecuteCommands):
+    def get_settings(self) -> Dict[str, Any]:
         """Returns the appium server Settings for the current session.
 
         Do not get Settings confused with Desired Capabilities, they are
@@ -37,7 +34,7 @@ class Settings(webdriver.Remote):
         """
         return self.execute(Command.GET_SETTINGS, {})['value']
 
-    def update_settings(self: T, settings: Dict[str, Any]) -> T:
+    def update_settings(self, settings: Dict[str, Any]) -> 'WebDriver':
         """Set settings for the current session.
 
         For more on settings, see: https://github.com/appium/appium/blob/master/docs/en/advanced-concepts/settings.md
@@ -48,12 +45,10 @@ class Settings(webdriver.Remote):
         data = {"settings": settings}
 
         self.execute(Command.UPDATE_SETTINGS, data)
-        return self
+        return self  # type: ignore
 
-    # pylint: disable=protected-access
-    # noinspection PyProtectedMember
-    def _addCommands(self) -> None:
-        self.command_executor._commands[Command.GET_SETTINGS] = \
-            ('GET', '/session/$sessionId/appium/settings')
-        self.command_executor._commands[Command.UPDATE_SETTINGS] = \
-            ('POST', '/session/$sessionId/appium/settings')
+    def _add_commands(self) -> None:
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.GET_SETTINGS] = ('GET', '/session/$sessionId/appium/settings')
+        commands[Command.UPDATE_SETTINGS] = ('POST', '/session/$sessionId/appium/settings')
